@@ -13,6 +13,8 @@
 #' @param ... Formulas defining parameter distributions.
 #' @param correlation A correlation matrix for parameters or
 #'   the output of \code{\link{define_correlation}}.
+#' @param list_qdist List of resampling functions.
+#' @param list_multi List of multinomial parameters.
 #'   
 #' @return An object of class \code{resamp_definition}. 
 #'   Contains \code{list_qdist}, a list of quantile 
@@ -54,13 +56,12 @@ define_distrib <- function(...,
   define_distrib_(list_qdist, list_multi, correlation)
 }
 
+#' @rdname define_distrib
 define_distrib_ <- function(list_qdist, list_multi, correlation) {
   
-  stopifnot(
-    length(unique(names(list_qdist))) == length(list_qdist),
-    all(unlist(lapply(list_multi,
-                      function(x) "multinom" %in% class(x))))
-  )
+  if (any(duplicated(names(list_qdist)))) {
+    stop("Some parameter names are duplicated.")
+  }
   
   # additional checks
   # all parameters in list_multi are r_multi ou r_binom parameters
@@ -88,13 +89,13 @@ define_distrib_ <- function(list_qdist, list_multi, correlation) {
   )
 }
 
-#' Define That Parameters Belong to the Same Multinomial
+#' Define That Parameters Belong to the Same Multinomial 
 #' Distribution
 #' 
 #' @param x A vector of parameter names.
 #'   
 #' @return An object of class \code{multinomial}.
-#' 
+#'   
 define_multinom <- function(x) {
   char_var <- x
   
@@ -125,12 +126,13 @@ define_multinom <- function(x) {
 #' Uncertainty Analysis
 #' 
 #' Not all correlation need to be specified for all variable
-#' combinations, unspecified correlations are assumed to be
+#' combinations, unspecified correlations are assumed to be 
 #' 0.
 #' 
 #' @param ... A list of parameter names and correlation 
 #'   coeficients of the form \code{var1, var2, cor(var1, 
-#'   var2), var3, var4, cor(var3, var4), ...}
+#'   var2), var3, var4, cor(var3, var4), ...}.
+#' @param .dots Used to work around non-standard evaluation.
 #'   
 #' @return An object of class \code{correlation_matrix}.
 #' @export
@@ -149,10 +151,11 @@ define_correlation <- function(...) {
   define_correlation_(.dots)
 }
 
+#' @rdname define_correlation
 define_correlation_ <- function(.dots) {
-  stopifnot(
-    length(.dots) %% 3 == 0
-  )
+  if (! length(.dots) %% 3 == 0) {
+    stop("Incorrect number of elements in correlation definition, the correct form is A, B, cor(A, B)...")
+  }
   
   f <- function(i) {
     if (i %% 3 == 0) {
@@ -170,13 +173,18 @@ define_correlation_ <- function(.dots) {
     cor = unlist(list_res[seq(from = 3, to = length(list_res), by = 3)])
   )
   
-  stopifnot(
-    ! any(duplicated(
-      mapply(
-        function(x, y) paste(sort(c(x, y)), collapse = ""),
-        res$v1, res$v2
-      )))
-  )
+  if (any(res$cor >1) | any(res$cor < -1)) {
+    stop("Correlation values must be between -1 and 1.")
+  }
+  
+  if (any(duplicated(
+    mapply(
+      function(x, y) paste(sort(c(x, y)), collapse = ""),
+      res$v1, res$v2
+    )))) {
+    stop("A correlation is defined more than once.")
+  }
+  
   structure(res, class = c("correlation_matrix", class(res)))
 }
 
