@@ -13,32 +13,36 @@
 run_probabilistic <- function(model, resample, N) {
   
   stopifnot(
-    N > 0
+    N > 0,
+    ! is.null(N)
   )
   
+  if (! all(c(".cost", ".effect") %in% names(model))) {
+    stop("No cost and/or effect defined, probabilistic analysis unavailable.")
+  }
+  
   newdata <- eval_resample(resample, N)
   
-  init <- attr(model, "init")
-  cycles <- attr(model, "cycles")
-  method <- attr(model, "method")
-  list_models <- attr(model, "uneval_model_list")
-  
   list_res <- list()
   
-  for (i in seq_along(list_models)) {
-    message(sprintf("Running model '%s'...", names(list_models)[i]))
+  for (n in get_model_names(model)) {
+    message(sprintf("Resampling model '%s'...", n))
     list_res <- c(
       list_res,
       list(
         eval_model_newdata(
-          model = list_models[[i]], method = method,
-          old_parameters = get_parameters(model),
-          init = init, cycles = cycles, newdata = newdata
-        )
+          x = model,
+          model = n,
+          newdata = newdata) %>% 
+          dplyr::rowwise() %>% 
+          dplyr::do_(~ get_total_state_values(.$.mod)) %>% 
+          dplyr::bind_cols(newdata) %>% 
+          dplyr::ungroup()
       )
     )
   }
-  names(list_res) <- names(list_models)
+  
+  names(list_res) <- get_model_names(model)
   index <- seq_len(N)
   
   for (n in names(list_res)) {
@@ -78,11 +82,12 @@ eval_correlation <- function(x, var_names) {
 #' @param resample A \code{\link{define_distrib}} object.
 #' @param N > 0. Number of simulation to run.
 #'   
-#' @return A \code{data.frame} of resampled values with on
-#' column per parameter and \code{N} rows.
-#' 
-#' 
+#' @return A \code{data.frame} of resampled values with on 
+#'   column per parameter and \code{N} rows.
+#'   
+#' @keywords internal
 eval_resample <- function(resample, N) {
+  
   mat_p <- stats::pnorm(
     mvnfast::rmvn(
       n = N,
