@@ -187,12 +187,13 @@ test_that(
     B <- define_state(cost = 5, utility = 7)
     C <- define_state(cost = 4, utility = 4)
     sample_mod <- define_model(transition_matrix = sampleTM, A = A, B = B, C = C)
-    res <- run_models(sample_mod, cost = cost, effect = utility)
+    res <- run_models(sample_mod, cost = cost, effect = utility,
+                      method = "beginning")
     
     
     expect_output(
       print(res),
-      '1 Markov model run for 1 cycle.
+      "1 Markov model run for 1 cycle.
 
 Initial states:
 
@@ -200,8 +201,11 @@ Initial states:
 A 1000
 B    0
 C    0
+
+Counting method: 'beginning'.
+
   cost utility
-I 3800    4100',
+I 3800    4100",
       fixed = TRUE
     )
   }
