@@ -146,6 +146,18 @@ y"
         X1 = s2
       )
     )
+    expect_error(
+      heemod:::define_state_list(
+        X1 = define_state(x = 1, y = 2),
+        X2 = define_state(x = 1)
+      )
+    )
+    expect_error(
+      heemod:::define_state_list(
+        X1 = define_state(x = 1, y = 2),
+        X2 = define_state(x = 1, z = 2)
+      )
+    )
     expect_warning(
       heemod:::define_state_list(
         X1 = s1,
@@ -193,9 +205,7 @@ test_that(
     )
     expect_output(
       str(e_st),
-      "List of 2
- $ X1:'data.frame':	10 obs. of  2 variables:
-  ..$ markov_cycle: int [1:10] 1 2 3 4 5 6 7 8 9 10
+      "..$ markov_cycle: int [1:10] 1 2 3 4 5 6 7 8 9 10
   ..$ A           :",
       fixed = TRUE
     )
@@ -213,4 +223,58 @@ test_that(
   }
 )
 
-
+test_that(
+  "Discounting works", {
+    
+    par1 <- define_parameters(
+      a = .1,
+      b = 1 / (markov_cycle + 1),
+      cte1 = 234,
+      cte2 = 123,
+      cte3 = 987,
+      cte4 = 1726
+    )
+    mat1 <- define_matrix(
+      state_names = c("X1", "X2"),
+      1-a, a,
+      1-b, b
+    )
+    s1 <- define_state(
+      x = discount(234, .05),
+      y = discount(123, .1) * 1
+    )
+    f <- function(x) x
+    s2 <- define_state(
+      x = f(discount(987, .2)),
+      y = discount(r = .1, 1726)
+    )
+    mod1 <- define_model(
+      transition_matrix = mat1,
+      X1 = s1,
+      X2 = s2
+    )
+    s3 <- define_state(
+      x = discount(cte1, .05),
+      y = discount(cte2, .1)
+    )
+    s4 <- define_state(
+      x = discount(cte3, .2),
+      y = discount(cte4, .1)
+    )
+    mod2 <- define_model(
+      transition_matrix = mat1,
+      X1 = s3,
+      X2 = s4
+    )
+    res <- run_models(
+      mod1, mod2,
+      parameters = par1, cost = x, effect = y
+    )
+    
+    expect_output(
+      print(res),
+      "   Cost Effect ICER
+II    0      0    -"
+    )
+  }
+)
\ No newline at end of file
